/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.planning.tactical;

import nl.cloudfarming.client.model.FieldPlan;
import nl.cloudfarming.client.planning.PlanEventKey;
import nl.cloudfarming.eventbus.GuiEvent;
import nl.cloudfarming.eventbus.GuiEventKey;

/**
 * Event which is used to let others know something has changed in a fieldPlan 
 * @author Merijn Zengers
 */
public class FieldPlanEvent implements GuiEvent<FieldPlan>{

        private final FieldPlan fieldPlan;
        private final PlanEventKey key;

        /**
         * Constructor
         * @param fieldPlan: the fieldplan for which the event is triggered
         * @param key: the event key. Which action has been done to trigger this event. 
         */
        public FieldPlanEvent(FieldPlan fieldPlan, PlanEventKey key) {
            this.fieldPlan = fieldPlan;
            this.key = key;
        }

        @Override
        public GuiEventKey getKey() {
            return key;
        }

        @Override
        public FieldPlan getContent() {
            return fieldPlan;
        }

    }
