/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.planning.tactical;

import java.beans.IntrospectionException;
import java.util.List;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;
import javax.swing.Action;
import nl.cloudfarming.client.model.AgroSenseBeanNode;
import nl.cloudfarming.client.model.FieldPlan;
import nl.cloudfarming.client.model.ProductionUnit;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.Exceptions;
import org.openide.util.NbBundle;
import org.openide.util.lookup.Lookups;

/**
 *
 * @author Timon Veenstra
 */
public class FieldPlanManager {

    private final static String FIELDPLAN_NODE_ICON = "nl/cloudfarming/client/icon/green-icon.png";
    
    private final FieldPlan fieldPlan;
    private final ProductionUnitNodeFactory productionUnitNodeFactory = new ProductionUnitNodeFactory();
    private final ConcurrentMap<ProductionUnit, ProductionUnitManager> productionUnitMap = new ConcurrentHashMap<ProductionUnit, ProductionUnitManager>();
    private final ProductionUnitManager unoccupiedFieldManager;
    private final ProductionUnitManager importedFieldManager;

    public FieldPlanManager(FieldPlan fieldPlan) {
        this.fieldPlan = fieldPlan;
        // production unit for unoccupied fields
        ProductionUnit unoccupiedUnit = ProductionUnit.UNOCCUPIED;
        unoccupiedFieldManager = new ProductionUnitManager(unoccupiedUnit);
        productionUnitMap.put(unoccupiedUnit, unoccupiedFieldManager);
        
        // Production unit for imported data
        ProductionUnit importUnit = ProductionUnit.IMPORT;
        importedFieldManager = new ProductionUnitManager(importUnit);
        productionUnitMap.put(importUnit, importedFieldManager);
    }

    Node getRootNode() {
        try {
            return new FieldPlanNode(fieldPlan);
        } catch (IntrospectionException ex) {
            Exceptions.printStackTrace(ex);
            return null;
        }
    }

    ProductionUnitManager getUnoccupiedFieldsManager() {
        return unoccupiedFieldManager;
    }
        
    ProductionUnitManager getImportedFieldsManager() {
        return importedFieldManager;
    }
    
    ProductionUnitManager getManagerForProductionUnit(ProductionUnit productionUnit){
        return productionUnitMap.get(productionUnit);
    }

    ProductionUnitManager addProductionUnit(ProductionUnit productionUnit) {
        //FIXME
        if (productionUnit.getName() == null) {
            productionUnit.setName(" " + productionUnit.getRaceKey());
        }
        ProductionUnitManager pum = new ProductionUnitManager(productionUnit);
        productionUnitMap.putIfAbsent(productionUnit, pum);
        productionUnitNodeFactory.refresh();
        return pum;
    }

    class FieldPlanNode extends AgroSenseBeanNode<FieldPlan> {

        public FieldPlanNode(FieldPlan fieldPlan) throws IntrospectionException {
            super(fieldPlan, Children.create(productionUnitNodeFactory, true), Lookups.fixed(fieldPlan));
            setIconBaseWithExtension(FIELDPLAN_NODE_ICON);
        }

        @Override
        public Action[] getActions(boolean context) {
            return new Action[]{new PlanProductionUnitController()};
        }
    }

    class ProductionUnitNodeFactory extends ChildFactory<ProductionUnitManager> {

        public ProductionUnitNodeFactory() {
        }

        @Override
        protected Node createNodeForKey(ProductionUnitManager key) {
            return key.getRootNode();
        }

        @Override
        protected boolean createKeys(List<ProductionUnitManager> toPopulate) {
            toPopulate.addAll(productionUnitMap.values());
            return true;
        }

        void refresh() {
            refresh(true);
        }
    }
}
