/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */
package nl.cloudfarming.client.planning.tactical;

import java.util.Set;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.model.FieldPlan;
import nl.cloudfarming.client.model.PartField;
import nl.cloudfarming.client.model.ProductionUnit;
import nl.cloudfarming.client.util.PanelStyle;
import org.jdesktop.swingx.JXPanel;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;

/**
 *
 * @author Timon Veenstra
 */
public class LinkProductionUnitToFieldPanel extends JXPanel {

    private static final String LABEL_PRODUCTION_UNIT = NbBundle.getMessage(LinkProductionUnitToFieldController.class, "action.link_production_unit_to_field.dialog.label.production_unit");
    private static final String LABEL_FIELD_PLAN = NbBundle.getMessage(LinkProductionUnitToFieldController.class, "action.link_production_unit_to_field.dialog.label.fieldplan");
    private static final String DIALOG_COMBOBOX_PRODUCTION_UNIT_DEFAULT_VALUE = NbBundle.getMessage(LinkProductionUnitToFieldController.class, "action.link_production_unit_to_field.dialog.combobox.field_plans.default_value");
    private static final String DIALOG_COMBOBOX_FIELD_PLAN_DEFAULT_VALUE = NbBundle.getMessage(LinkProductionUnitToFieldController.class, "action.link_production_unit_to_field.dialog.combobox.production_units.default_value");
    private final TacticalPlanningService service = Lookup.getDefault().lookup(TacticalPlanningService.class);
    private final JComboBox productionUnitBox= new JComboBox();;

    public LinkProductionUnitToFieldPanel(PartField partField) {
        super(new MigLayout("wrap 2"));

        // Introtekst #1        
        add(new JLabel(NbBundle.getMessage(LinkProductionUnitToFieldController.class, "action.link_production_unit_to_field.dialog.introtekst1", partField.getId(), partField.getName())), PanelStyle.INTROTEKST_TOP);

        // ProductionUnit ComboBox
        add(new JLabel(LABEL_PRODUCTION_UNIT));
        add(productionUnitBox, PanelStyle.GAP_LABEL_AND_COMPONENT);
    }

    public JComboBox getProductionUnitBox() {
        return productionUnitBox;
    }
    
    
    
    public void populateProductionUnitBox(FieldPlan fieldPlan){
     // Find all productions units that belong to the selected fieldplan    
        Set<ProductionUnit> productionUnits = fieldPlan.getProductionUnits();

        if (productionUnits.isEmpty()) {
            productionUnitBox.removeAllItems();
            productionUnitBox.addItem(DIALOG_COMBOBOX_FIELD_PLAN_DEFAULT_VALUE);
            productionUnitBox.setEnabled(false);
//            jButtonOK.setEnabled(false);
        } else {
            productionUnitBox.removeAllItems();
            for (ProductionUnit productionUnit : productionUnits) {
                productionUnitBox.addItem(productionUnit);
            }
            productionUnitBox.setEnabled(true);
//            jButtonOK.setEnabled(true);
        }        
    }
    
}
