/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.planning.tactical;

import java.awt.datatransfer.Transferable;
import java.beans.IntrospectionException;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import javax.swing.Action;
import nl.cloudfarming.client.model.AgroSenseBeanNode;
import nl.cloudfarming.client.model.Bean;
import nl.cloudfarming.client.model.Operation;
import nl.cloudfarming.client.model.Task;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.Exceptions;
import org.openide.util.lookup.Lookups;

/**
 *
 * @author Gerben Feenstra & Merijn Zengers
 */
public class OperationManager {
   
    private final Operation operation;
    private Node rootNode;
    private final TaskNodeFactory taskNodeFactory;   
    private final List<Task> tasks = Collections.synchronizedList(new ArrayList<Task>());
    private static int opCounter = 1;
    private static int taskCounter = 1;
    
    public OperationManager(Operation operation) {
        assert operation != null : "Operation is required argument and cannot be null";
        this.operation = operation;
        taskNodeFactory = new TaskNodeFactory();
        try {
            rootNode = new OperationNode(operation);
        } catch (IntrospectionException ex) {
            Exceptions.printStackTrace(ex);
        }
        addTask(new Task());
    }

    Node getRootNode() {
        return rootNode;
    }
    
    void addTask(Task task) {
        tasks.add(task);
        taskNodeFactory.refresh();
    }

    void removeTask(Task task) {
        tasks.remove(task);
        taskNodeFactory.refresh();
    }
    
    List<Task> getTasks() {
        return tasks;
    }
    
    class OperationNode extends AgroSenseBeanNode<Bean> {
        public OperationNode(Operation key) throws IntrospectionException {
            super(key, Children.create(taskNodeFactory, true), Lookups.fixed(key));

            //FIXME icon for operation node
    //        setIconBaseWithExtension("");
            Operation.Type opType = key.getType();
            String opTypeStr = "";
            if(opType != null){
                opTypeStr = opType.toString() + " ";
            }
            
            setName(opTypeStr + "Operation " + opCounter++);
        }

    }
    
    class TaskNode extends AbstractNode {
        public TaskNode(Task key) {
            super(Children.LEAF, Lookups.fixed(key));
            //FIXME icon for operation node
    //        setIconBaseWithExtension("");
            setName("Task dummy " + taskCounter++);//key.getType().toString());
        }

    }
     class TaskNodeFactory extends ChildFactory<Task> {

        @Override
        protected Node createNodeForKey(Task key) {
            return new TaskNode(key);
        }

        
        @Override
        protected boolean createKeys(List<Task> toPopulate) {
            toPopulate.addAll(getTasks());
            return true;
        }

        private void refresh() {
            refresh(true);
        }
        
    }
    

}
