/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */
package nl.cloudfarming.client.planning.tactical;

import java.util.Collection;
import java.util.Date;
import java.util.List;
import nl.cloudfarming.client.model.*;
import nl.cloudfarming.client.model.crop.Race;

/**
 *
 * @author Timon Veenstra
 */
public interface TacticalPlanningService extends BeanService {

    /**
     * Property for palettes
     * When a new palette gets introduced the change event will contain
     * null as old value and the palette as new value.
     * When a palettes gets removed, the change event will contain the palette
     * as old value and null as new value
     * 
     */
    public static final String PROP_PALETTES = "prop_palettes";

    /**
     * Creates an FieldPlan within a transaction. Starts a transaction if it is
     * not already started.
     *
     * @param year for which Fieldplan is created
     */
    FieldPlan createFieldPlanForYear(String name, int year);

    /**
     * 
     * @param operation used as parameter
     * @return persisted Operation
     */
    Operation planOperation(ProductionUnit productionUnit, Operation.Type type, Date planDate);

    /**
     * Creates a productionUnit within a transaction. 
     * @param fieldPlan 
     * @param race 
     * @param startDate 
     * @param endDate 
     * @return
     */
    ProductionUnit createProductionUnit(FieldPlan fieldPlan, Race race, Date startDate, Date endDate);

    /**
     * Import operations into a fieldplan.
     * An import production unit will be created and the provided operations
     * will be added to that production unit.
     * The produiction unit will be added to the fieldplan and returned.
     * 
     * @param fieldplan
     * @param operations
     * @return 
     */
    ProductionUnit importOperations(FieldPlan fieldplan, List<Operation> operations);

    /**
     * Link an unoccupied partfield to a production unit
     * 
     * @param partField
     * @param productionUnit 
     */
    void linkPartFieldToProductionUnit(PartField partField, ProductionUnit productionUnit);

    /**
     * Find all partfields for a fieldplan which are not linked
     * to a production unit.
     * 
     * @param fieldPlan
     * @return collection with unoccupied partfields
     */
    Collection<PartField> findUnoccupiedPartFields(FieldPlan fieldPlan);
    
    Collection<PartField> findImportedFields(FieldPlan fieldPlan);
}