/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.planning.tactical.wizard;

import java.awt.Component;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.util.ArrayList;
import javax.swing.DefaultComboBoxModel;
import javax.swing.JComboBox;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import nl.cloudfarming.client.planning.wizard.PlanningWizardAction;
import org.openide.WizardDescriptor;
import org.openide.util.HelpCtx;
import org.openide.util.Lookup;

/**
 * Controller of class ActionSelectionPanel.class
 * Will store and update panel model of JCombobox.
 * Will Determine available wizards based on ServiceProvider of type PlanningWizardAction.class
 * @author Merijn Zengers
 */
public class ActionSelectionController implements ItemListener, WizardDescriptor.Panel {

    private ActionSelectionPanel component;
    private ArrayList<PlanningWizardAction> wizards;
    public static final String SELECTED_ACTION = "selectedAction";
    private ArrayList<ChangeListener> changeListeners = new ArrayList<ChangeListener>();

    /**
     * Gets the component this controller controls
     * @return the Component
     */
    @Override
    public Component getComponent() {
        if (component == null) {
            component = new ActionSelectionPanel();
            JComboBox actions = ((ActionSelectionPanel) getComponent()).getActions();
            actions.addItemListener(this);
        }
        return component;
    }

    @Override
    public HelpCtx getHelp() {
        // Show no Help button for this panel:
        return HelpCtx.DEFAULT_HELP;
        // If you have context help:
        // return new HelpCtx(SampleWizardPanel1.class);
    }

    /**
     * Read the stored settings and set the selected item on the Components JCombobox
     * @param settings 
     */
    @Override
    public void readSettings(Object settings) {
        if (wizards == null) {
            wizards = new ArrayList<PlanningWizardAction>(Lookup.getDefault().lookupAll(PlanningWizardAction.class));
            ((ActionSelectionPanel) getComponent()).getActions().setModel(new DefaultComboBoxModel(wizards.toArray()));
        }
        if (settings != null) {
            ((ActionSelectionPanel) getComponent()).getActions().setSelectedItem(PlanningWizardProperties.getAction((WizardDescriptor)settings));
        }
    }

    /**
     * Store the input the user has given on exit
     * @param settings the wizardDescriptor which contains the input
     */
    @Override
    public void storeSettings(Object settings) {
        JComboBox actions = ((ActionSelectionPanel) getComponent()).getActions();
        if (actions != null) {
            PlanningWizardProperties.setAction((PlanningWizardAction)actions.getSelectedItem(),(WizardDescriptor) settings);
        }
    }

    /**
     * Is the panel valid? Is always true.
     * @return 
     */
    @Override
    public boolean isValid() {
        return true;
    }

    @Override
    public void addChangeListener(ChangeListener l) {
        changeListeners.add(l);
    }

    @Override
    public void removeChangeListener(ChangeListener l) {
        changeListeners.remove(l);
    }

    /**
     * If the state of the Components JCombobox changes the listeners need to be informed. 
     * @param e The itemEvent which triggered this itemStateChanged
     */
    @Override
    public void itemStateChanged(ItemEvent e) {
        JComboBox actions = ((ActionSelectionPanel) getComponent()).getActions();
        for (ChangeListener listener : changeListeners) {
            listener.stateChanged(new ChangeEvent(actions));
        }
    }
}
