/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.planning.tactical.wizard;

import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.planning.tactical.TacticalPlanningModule;
import org.openide.util.NbBundle;

/**
 * Panel which displays choice of selectable wizards.
 * @author Merijn Zengers
 */
public class ActionSelectionPanel extends JPanel {
    private JLabel actionSelectionLabel;
    private JComboBox actions;
    
    
    private static final String TITLE = NbBundle.getMessage(TacticalPlanningModule.class, "field_plan.wizard.select.name");
    private static final String ACTION_SELECTION_LABEL= NbBundle.getMessage(TacticalPlanningModule.class, "field_plan.wizard.select.label.selection");
    
    
    /** Creates new form PlanningVisualPanel1 */
    public ActionSelectionPanel() {
        initComponents();       
    }

    /**
     * Returns the name of this wizard panel
     * @return the name of this wizard panel
     */
    @Override
    public String getName() {
        return TITLE;
    }

    /**
     * Gets the JCombobox which displays the available wizards 
     * @return JComboBox containing all the wizard options
     */
    public JComboBox getActions() {
        return actions;
    }
    
    
    /** 
     * This method is called from within the constructor to
     * initialize the form.
     */
    private void initComponents() {
        setLayout(new MigLayout("wrap 2"));
        actionSelectionLabel = new JLabel(ACTION_SELECTION_LABEL);
        actions = new JComboBox();
        this.add(actionSelectionLabel);    
        this.add(actions);
    }
}
