/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.planning.tactical.wizard.spray;

import java.awt.Component;
import java.util.ArrayList;
import java.util.List;
import javax.swing.event.ChangeListener;
import nl.cloudfarming.client.model.ProductionUnit;
import nl.cloudfarming.client.model.Remedy;
import nl.cloudfarming.client.planning.tactical.TacticalPlanningModule;
import nl.cloudfarming.client.stock.StockService;
import org.openide.WizardDescriptor;
import org.openide.WizardValidationException;
import org.openide.util.HelpCtx;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.util.Utilities;

public class RemedyController implements WizardDescriptor.ValidatingPanel {

    private static final String MSG_INVALID_SELECTED_CROPPROTECIONS = NbBundle.getMessage(TacticalPlanningModule.class, "field_plan.wizard.spray.planning_visual_panel_crop_protection_edit_properties.validation.invalid_cropprotection_selection");
    private List<Remedy> remedyList;
    /**
     * The visual component that displays this panel. If you need to access the
     * component from this class, just use getComponent().
     */
    private RemedyPanel panel;

    // Get the visual component for the panel. In this template, the component
    // is kept separate. This can be more efficient: if the wizard is created
    // but never displayed, or not all panels are displayed, it is better to
    // create only those which really need to be visible.
    @Override
    public Component getComponent() {
        if (panel == null) {
            panel = new RemedyPanel();
        }
        return panel;
    }

    @Override
    public HelpCtx getHelp() {
        // Show no Help button for this panel:
        return HelpCtx.DEFAULT_HELP;
        // If you have context help:
        // return new HelpCtx(SampleWizardPanel1.class);
    }

    @Override
    public boolean isValid() {
        // If it is always OK to press Next or Finish, then:
        return true;
        // If it depends on some condition (form filled out...), then:
        // return someCondition();
        // and when this condition changes (last form field filled in...) then:
        // fireChangeEvent();
        // and uncomment the complicated stuff below.
    }

    @Override
    public final void addChangeListener(ChangeListener l) {
    }

    @Override
    public final void removeChangeListener(ChangeListener l) {
    }

    // You can use a settings object to keep track of state. Normally the
    // settings object will be the WizardDescriptor, so you can use
    // WizardDescriptor.getProperty & putProperty to store information entered
    // by the user.
    @Override
    public void readSettings(Object settings) {
        StockService cps = Lookup.getDefault().lookup(StockService.class);
        ProductionUnit pu = Utilities.actionsGlobalContext().lookup(ProductionUnit.class);
        assert (cps != null);
        assert (pu != null);
        remedyList = cps.getAllRemedies(pu.getRace().getCrop());

        panel.setAvailableRemedies(remedyList);
    }

    @Override
    public void storeSettings(Object settings) {
        List<Remedy> selectedRemedies = ((RemedyPanel) getComponent()).getSelectedRemedies();
        SprayWizardProperties.setRemedies(selectedRemedies, (WizardDescriptor) settings);
    }

    @Override
    public void validate() throws WizardValidationException {
        if (((RemedyPanel) panel).getSelectedRemedies().isEmpty()) {
            throw new WizardValidationException(null, MSG_INVALID_SELECTED_CROPPROTECIONS, null);
        }
    }
}
