/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.planning.tactical.wizard.spray;

import java.awt.Dimension;
import java.awt.Font;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.ScrollPaneLayout;
import javax.swing.table.AbstractTableModel;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.model.ProductionUnit;
import nl.cloudfarming.client.planning.tactical.TacticalPlanningModule;
import org.openide.util.NbBundle;
import org.openide.util.Utilities;

/**
 * Spraywizard Summarypanel
 * 
 * @author Gerben Feenstra
 */
public final class SummaryPanel extends JPanel {
    
    private static final String TITLE = NbBundle.getMessage(TacticalPlanningModule.class, "field_plan.wizard.spray.summary_panel.title"); 
    
    private final JLabel labelHeaderText = new JLabel(NbBundle.getMessage(TacticalPlanningModule.class, "field_plan.wizard.spray.summary_panel.header_text"));
 
    private static final int PREFERED_PANE_HEIGHT = 200;
    private static final int PREFERED_PANE_WIDTH = 700;
    
    // Text Labels
    private static final String LABEL_FIELDPLAN_LABEL_TEXT = NbBundle.getMessage(TacticalPlanningModule.class, "field_plan.wizard.common.label.fieldplan");
    private static final String LABEL_PU = NbBundle.getMessage(TacticalPlanningModule.class, "field_plan.wizard.common.label.production_unit_name");
    private static final String LABEL_CROP = NbBundle.getMessage(TacticalPlanningModule.class, "field_plan.wizard.common.label.crop");
    private static final String LABEL_PU_START_DATE = NbBundle.getMessage(TacticalPlanningModule.class, "field_plan.wizard.common.label.production_unit_name_start_date");
    private static final String LABEL_PU_END_DATE = NbBundle.getMessage(TacticalPlanningModule.class, "field_plan.wizard.common.label.production_unit_name_end_date");     
    private static final String LABEL_OPERATION = NbBundle.getMessage(TacticalPlanningModule.class, "field_plan.wizard.common.label.operation");  
    private static final String LABEL_ACTION_PLAN_DATE = NbBundle.getMessage(TacticalPlanningModule.class, "field_plan.wizard.common.label.action_planned_date");  
    private static final String ACTION_NAME = NbBundle.getMessage(TacticalPlanningModule.class,"field_plan.wizard.spray.planning_wizard_action.operation_name");
    
    private static final String LABEL_GAP = "gapleft 20";

    private static final String MODEL_COLUMNNAME_ID = NbBundle.getMessage(TacticalPlanningModule.class, "field_plan.wizard.spray.crop_protection_list_panel.crop_header_id");
    private static final String MODEL_COLUMNNAME_PESTICIDE = NbBundle.getMessage(TacticalPlanningModule.class, "field_plan.wizard.spray.crop_protection_list_panel.crop_header_pesticide");
    private static final String MODEL_COLUMNNAME_APPLICATION = NbBundle.getMessage(TacticalPlanningModule.class, "field_plan.wizard.spray.crop_protection_list_panel.crop_header_application");
    private static final String MODEL_COLUMNNAME_QUANTITY = NbBundle.getMessage(TacticalPlanningModule.class, "field_plan.wizard.spray.planning_visual_panel_crop_protection_edit_properties.columnheader.quantity");
    private static final String MODEL_COLUMNNAME_CONCENTRATION = NbBundle.getMessage(TacticalPlanningModule.class, "field_plan.wizard.spray.planning_visual_panel_crop_protection_edit_properties.columnheader.concentration");
    private static final String[] MODEL_COLUMNNAMES = new String[]{MODEL_COLUMNNAME_ID, MODEL_COLUMNNAME_PESTICIDE, MODEL_COLUMNNAME_APPLICATION, MODEL_COLUMNNAME_QUANTITY, MODEL_COLUMNNAME_CONCENTRATION};

    // Value labels  
    private ProductionUnit productionUnit = Utilities.actionsGlobalContext().lookup(ProductionUnit.class);
    private final JLabel fieldplanValue = new JLabel(Integer.toString(productionUnit.getFieldPlan().getPlanYear())); // fieldplan year
    private final JLabel pUValue = new JLabel(productionUnit.getName()); // Name
    private final JLabel cropValue = new JLabel(productionUnit.getRace().getCrop().getName()); // Crop name
    private final JLabel pUStartDateValue = new JLabel(); // Pu startdate
    private final JLabel pUEndDateValue = new JLabel();
    private final JLabel operationValue = new JLabel(ACTION_NAME); // Currently we only have spraying operations   
    private final JLabel actionPlanDateValue = new JLabel();

    // Text-only labels
    private static final String SPRAYING_TITLE_LABEL_TEXT = NbBundle.getMessage(TacticalPlanningModule.class, "field_plan.wizard.spray.summary_panel.label.title");      
    private static final String ACTION_PLANNED = NbBundle.getMessage(TacticalPlanningModule.class, "field_plan.wizard.common.text.action_planned");  
    
    private String[][] selectedCropProtectionTasks;
    private SummaryTableModel summaryTableModel;   
    private JTable summaryTable;
    private JScrollPane scrollPane;    
    
    /** Creates new form SummaryPanel */
    public SummaryPanel() {
        initComponents();
    }

    @Override
    public String getName() {
        return TITLE;
    }

    private void initComponents() {
        setLayout(new MigLayout("wrap 2"));
 
        this.add(labelHeaderText, "gapbottom 10, span");
//        // Gap
//        this.add(new JLabel(""), "gaptop 10, span"); 
                
        // Declare all labels
        JLabel fieldPlanLabel = new JLabel(LABEL_FIELDPLAN_LABEL_TEXT);
        JLabel puLabel = new JLabel(LABEL_PU);
        JLabel cropLabel = new JLabel(LABEL_CROP);
        JLabel puStartDateLabel = new JLabel(LABEL_PU_START_DATE);
        JLabel puEndDateLabel = new JLabel(LABEL_PU_END_DATE);
        JLabel operationLabel = new JLabel(LABEL_OPERATION);
        JLabel actionPlanDateLabel = new JLabel(LABEL_ACTION_PLAN_DATE);
        JLabel actionPlannedLabel = new JLabel(ACTION_PLANNED);
        JLabel tableTitleLabel = new JLabel(SPRAYING_TITLE_LABEL_TEXT);
        // Derive font from fieldPlanLabel, create new Bold font.
        Font font = fieldPlanLabel.getFont();
        Font boldFont = new Font(font.getName(), Font.BOLD, font.getSize());
        
        // Set all labels to bold
        fieldPlanLabel.setFont(boldFont);
        puLabel.setFont(boldFont);
        cropLabel.setFont(boldFont);
        puStartDateLabel.setFont(boldFont);
        puEndDateLabel.setFont(boldFont);     
        operationLabel.setFont(boldFont);   
        actionPlanDateLabel.setFont(boldFont);
                
        // Add all labels
        this.add(fieldPlanLabel);
        this.add(fieldplanValue, LABEL_GAP);
        
        this.add(puLabel);
        this.add(pUValue, LABEL_GAP);
        
        this.add(cropLabel);
        this.add(cropValue, LABEL_GAP);
        
        this.add(puStartDateLabel);
        this.add(pUStartDateValue, LABEL_GAP);
   
        this.add(puEndDateLabel);
        this.add(pUEndDateValue, LABEL_GAP);
        
        // The following action will be planned
        this.add(actionPlannedLabel, "gaptop 30, gapbottom 10, span"); 
        
        this.add(operationLabel);
        this.add(operationValue, LABEL_GAP);
        
//        // Gap
//        this.add(new JLabel(""), "gaptop 10, span");
                
        this.add(actionPlanDateLabel);
        this.add(actionPlanDateValue, LABEL_GAP);
        
        this.add(tableTitleLabel, "gaptop 20, wrap");

        // Create Table and Scrollpane to display table on
        summaryTableModel = new SummaryTableModel();
        summaryTable = new JTable(summaryTableModel);      
        summaryTable.setRowSelectionAllowed(false);
        summaryTable.setColumnSelectionAllowed(false);
        summaryTable.setEnabled(false);
        scrollPane = new JScrollPane();
        scrollPane.setPreferredSize(new Dimension(PREFERED_PANE_WIDTH, PREFERED_PANE_HEIGHT));
        scrollPane.setLayout(new ScrollPaneLayout());
        scrollPane.setViewportView(summaryTable);
        this.add(scrollPane, "span");    
    }

    /**
     * @param selectedCropProtections 
     */
    public void setSelectedCropProtectionTasks(String[][] selectedCropProtectionTasks) {
        this.selectedCropProtectionTasks = selectedCropProtectionTasks.clone();
        summaryTableModel.setData(this.selectedCropProtectionTasks);        
        summaryTable.clearSelection();
    }
   
    public String[][] getSelectedCropProtectionTasksProperties() {
        String[][] cropProtectionProperties = new String[summaryTableModel.getRowCount()][summaryTableModel.getColumnCount()];
        for (int i = 0; i < summaryTableModel.getRowCount(); i++) {
            for (int j = 0; j < summaryTableModel.getColumnCount(); j++) {
                cropProtectionProperties[i][j] = (String) summaryTableModel.getValueAt(i, j);
            }
        }
        return cropProtectionProperties;
    }
        
    public JLabel getActionPlanDateLabel() {
        return actionPlanDateValue;
    }
    
    public JLabel getOperationLabel() {
        return operationValue;
    }
    
    public JLabel getProductionUnitEnddateLabel() {
        return pUEndDateValue;
    }
           
    public JLabel getProductionUnitStartdateLabel() {
        return pUStartDateValue;
    }        
    
    public JLabel getFieldplanLabel(){
        return fieldplanValue;
    }
    
    public JLabel getProductionUnitLabel(){
        return pUValue;
    }
            
    public JLabel getCropLabel() {
        return cropValue;
    }

    /**
     * Custom tableModel. this can be instantiated without data. Use the setData method to display data
     */
    private class SummaryTableModel extends AbstractTableModel {

        private Object[][] data = new Object[0][0];

        public SummaryTableModel() {
        }

        public void setData(Object[][] data) {
            this.data = data.clone();
        }

        @Override
        public int getColumnCount() {
            return MODEL_COLUMNNAMES.length;
        }

        @Override
        public int getRowCount() {
            return data.length;
        }

        @Override
        public String getColumnName(int col) {
            return MODEL_COLUMNNAMES[col];
        }

        @Override
        public Object getValueAt(int row, int col) {
            return data[row][col];
        }

        @Override
        public Class getColumnClass(int c) {
            return getValueAt(0, c).getClass();
        }
        
        // Table should not be editable
        @Override
        public boolean isCellEditable(int x, int y){
            return false;
        }
        
    }
}
